@@ -1,6 +1,8 @@
 package view
 
 import (
+	"fmt"
+
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
 
@@ -16,7 +18,20 @@ const (
 	examples = `$ jira issue view ISSUE-1
 
 # Show 5 recent comments when viewing the issue
-$ jira issue view ISSUE-1 --comments 5`
+$ jira issue view ISSUE-1 --comments 5
+
+# Get the raw JSON data
+$ jira issue view ISSUE-1 --raw`
+
+	flagRaw      = "raw"
+	flagDebug    = "debug"
+	flagComments = "comments"
+	flagPlain    = "plain"
+
+	configProject = "project.key"
+	configServer  = "server"
+
+	messageFetchingData = "Fetching issue details..."
 )
 
 // NewCmdView is a view command.
@@ -34,22 +49,52 @@ func NewCmdView() *cobra.Command {
 		Run:  view,
 	}
 
-	cmd.Flags().Uint("comments", 1, "Show N comments")
-	cmd.Flags().Bool("plain", false, "Display output in plain mode")
+	cmd.Flags().Uint(flagComments, 1, "Show N comments")
+	cmd.Flags().Bool(flagPlain, false, "Display output in plain mode")
+	cmd.Flags().Bool(flagRaw, false, "Print raw Jira API response")
 
 	return &cmd
 }
 
 func view(cmd *cobra.Command, args []string) {
-	debug, err := cmd.Flags().GetBool("debug")
+	raw, err := cmd.Flags().GetBool(flagRaw)
 	cmdutil.ExitIfError(err)
 
-	comments, err := cmd.Flags().GetUint("comments")
+	if raw {
+		viewRaw(cmd, args)
+		return
+	}
+	viewPretty(cmd, args)
+}
+
+func viewRaw(cmd *cobra.Command, args []string) {
+	debug, err := cmd.Flags().GetBool(flagDebug)
 	cmdutil.ExitIfError(err)
 
-	key := cmdutil.GetJiraIssueKey(viper.GetString("project.key"), args[0])
+	key := cmdutil.GetJiraIssueKey(viper.GetString(configProject), args[0])
+
+	apiResp, err := func() (string, error) {
+		s := cmdutil.Info(messageFetchingData)
+		defer s.Stop()
+
+		client := api.DefaultClient(debug)
+		return api.ProxyGetIssueRaw(client, key)
+	}()
+	cmdutil.ExitIfError(err)
+
+	fmt.Println(apiResp)
+}
+
+func viewPretty(cmd *cobra.Command, args []string) {
+	debug, err := cmd.Flags().GetBool(flagDebug)
+	cmdutil.ExitIfError(err)
+
+	comments, err := cmd.Flags().GetUint(flagComments)
+	cmdutil.ExitIfError(err)
+
+	key := cmdutil.GetJiraIssueKey(viper.GetString(configProject), args[0])
 	iss, err := func() (*jira.Issue, error) {
-		s := cmdutil.Info("Fetching issue details...")
+		s := cmdutil.Info(messageFetchingData)
 		defer s.Stop()
 
 		client := api.DefaultClient(debug)
@@ -57,11 +102,11 @@ func view(cmd *cobra.Command, args []string) {
 	}()
 	cmdutil.ExitIfError(err)
 
-	plain, err := cmd.Flags().GetBool("plain")
+	plain, err := cmd.Flags().GetBool(flagPlain)
 	cmdutil.ExitIfError(err)
 
 	v := tuiView.Issue{
-		Server:  viper.GetString("server"),
+		Server:  viper.GetString(configServer),
 		Data:    iss,
 		Display: tuiView.DisplayFormat{Plain: plain},
 		Options: tuiView.IssueOption{NumComments: comments},
