@@ -400,9 +400,15 @@ func (i Issue) comments() []issueComment {
 			body = c.Body.(string)
 			body = md.FromJiraMD(body)
 		}
+		authorName := func() string {
+			if c.Author.DisplayName != "" {
+				return c.Author.DisplayName
+			}
+			return c.Author.Name
+		}
 		meta := fmt.Sprintf(
 			"\n %s • %s",
-			coloredOut(c.Author.Name, color.FgWhite, color.Bold),
+			coloredOut(authorName(), color.FgWhite, color.Bold),
 			coloredOut(cmdutil.FormatDateTimeHuman(c.Created, jira.RFC3339), color.FgWhite, color.Bold),
 		)
 		if idx == total-1 {
@@ -430,7 +436,7 @@ func (i Issue) footer() string {
 	if i.Display.Plain {
 		out.WriteString("\n")
 	}
-	out.WriteString(gray(fmt.Sprintf("View this issue on Jira: %s/browse/%s", i.Server, i.Data.Key)))
+	out.WriteString(gray(fmt.Sprintf("View this issue on Jira: %s", cmdutil.GenerateServerBrowseURL(i.Server, i.Data.Key))))
 
 	return out.String()
 }
