@@ -43,7 +43,7 @@ func WithServerInfoWriter(w io.Writer) ServerInfoOption {
 
 // Render renders the serverinfo view.
 func (s ServerInfo) Render() error {
-	fmt.Fprintf(s.writer, `SERVER INFO
+	_, _ = fmt.Fprintf(s.writer, `SERVER INFO
 -----------
 
 Version: 	 %s
