@@ -7,6 +7,8 @@ import (
 
 	"github.com/gdamore/tcell/v2"
 	"github.com/rivo/tview"
+
+	"github.com/ankitpokhrel/jira-cli/pkg/tui/primitive"
 )
 
 const (
@@ -25,6 +27,15 @@ type ViewModeFunc func(row, col int, data interface{}) (func() interface{}, func
 // RefreshFunc is fired when a user press 'CTRL+R' or `F5` character in the table.
 type RefreshFunc func()
 
+// RefreshTableStateFunc is used to refresh the table state.
+type RefreshTableStateFunc func(row, col int, val string)
+
+// MoveHandlerFunc is a handler for move action.
+type MoveHandlerFunc func(state string) error
+
+// MoveFunc is fired when a user press 'm' character in the table cell.
+type MoveFunc func(row, col int) func() (key string, actions []string, handler MoveHandlerFunc, status string, refresh RefreshTableStateFunc)
+
 // CopyFunc is fired when a user press 'c' character in the table cell.
 type CopyFunc func(row, column int, data interface{})
 
@@ -75,14 +86,19 @@ type Table struct {
 	painter      *tview.Pages
 	view         *tview.Table
 	footer       *tview.TextView
+	secondary    *tview.Modal
+	help         *primitive.InfoModal
+	action       *primitive.ActionModal
 	style        TableStyle
 	data         TableData
 	colPad       uint
 	colFixed     uint
 	maxColWidth  uint
 	footerText   string
+	helpText     string
 	selectedFunc SelectedFunc
 	viewModeFunc ViewModeFunc
+	moveFunc     MoveFunc
 	refreshFunc  RefreshFunc
 	copyFunc     CopyFunc
 	copyKeyFunc  CopyKeyFunc
@@ -99,6 +115,9 @@ func NewTable(opts ...TableOption) *Table {
 		screen:      NewScreen(),
 		view:        tview.NewTable(),
 		footer:      tview.NewTextView(),
+		help:        primitive.NewInfoModal(),
+		secondary:   getInfoModal(),
+		action:      getActionModal(),
 		colPad:      defaultColPad,
 		maxColWidth: defaultColWidth,
 	}
@@ -108,6 +127,7 @@ func NewTable(opts ...TableOption) *Table {
 
 	tbl.initTable()
 	tbl.initFooter()
+	tbl.initHelp()
 
 	grid := tview.NewGrid().
 		SetRows(0, 1, 2).
@@ -115,9 +135,18 @@ func NewTable(opts ...TableOption) *Table {
 		AddItem(tview.NewTextView(), 1, 0, 1, 1, 0, 0, false). // Dummy view to fake row padding.
 		AddItem(tbl.footer, 2, 0, 1, 1, 0, 0, false)
 
+	tbl.action.SetInputCapture(func(ev *tcell.EventKey) *tcell.EventKey {
+		if ev.Key() == tcell.KeyEsc || (ev.Key() == tcell.KeyRune && ev.Rune() == 'q') {
+			tbl.painter.HidePage("action")
+		}
+		return ev
+	})
+
 	tbl.painter = tview.NewPages().
 		AddPage("primary", grid, true, true).
-		AddPage("secondary", getInfoModal(), true, false)
+		AddPage("secondary", tbl.secondary, true, false).
+		AddPage("help", tbl.help, true, false).
+		AddPage("action", tbl.action, true, false)
 
 	return &tbl
 }
@@ -136,6 +165,13 @@ func WithTableFooterText(text string) TableOption {
 	}
 }
 
+// WithTableHelpText sets the help text for the view.
+func WithTableHelpText(text string) TableOption {
+	return func(t *Table) {
+		t.helpText = text
+	}
+}
+
 // WithSelectedFunc sets a func that is triggered when table row is selected.
 func WithSelectedFunc(fn SelectedFunc) TableOption {
 	return func(t *Table) {
@@ -150,6 +186,13 @@ func WithViewModeFunc(fn ViewModeFunc) TableOption {
 	}
 }
 
+// WithMoveFunc sets a func that is triggered when an action button is pressed.
+func WithMoveFunc(fn MoveFunc) TableOption {
+	return func(t *Table) {
+		t.moveFunc = fn
+	}
+}
+
 // WithRefreshFunc sets a func that is triggered when a user press 'CTRL+R' or 'F5'.
 func WithRefreshFunc(fn RefreshFunc) TableOption {
 	return func(t *Table) {
@@ -205,6 +248,21 @@ func (t *Table) initFooter() {
 		SetTextColor(tcell.ColorDefault)
 }
 
+func (t *Table) initHelp() {
+	t.help.
+		SetInfo(t.helpText).
+		SetAlign(tview.AlignLeft).
+		SetTitle("USAGE")
+
+	t.help.SetInputCapture(func(ev *tcell.EventKey) *tcell.EventKey {
+		if ev.Key() == tcell.KeyEsc || (ev.Key() == tcell.KeyRune && ev.Rune() == 'q') {
+			t.painter.HidePage("help")
+		}
+		return ev
+	})
+}
+
+//nolint:gocyclo
 func (t *Table) initTable() {
 	t.view.SetSelectable(true, false).
 		SetSelectedStyle(customTUIStyle(t.style)).
@@ -233,6 +291,8 @@ func (t *Table) initTable() {
 				case 'q':
 					t.screen.Stop()
 					os.Exit(0)
+				case '?':
+					t.painter.ShowPage("help")
 				case 'c':
 					if t.copyFunc == nil {
 						break
@@ -258,6 +318,65 @@ func (t *Table) initTable() {
 							}
 						}()
 
+						// Refresh the screen.
+						t.screen.Draw()
+					}()
+				case 'm':
+					if t.moveFunc == nil {
+						break
+					}
+
+					refreshContextInFooter := func() {
+						t.action.GetFooter().SetText("Use TAB or ← → to navigate, ENTER to select, ESC or q to cancel.").SetTextColor(tcell.ColorGray)
+					}
+
+					go func() {
+						func() {
+							t.painter.ShowPage("secondary").SendToFront("secondary")
+							defer func() {
+								t.painter.HidePage("secondary")
+								t.painter.ShowPage("action")
+							}()
+							refreshContextInFooter()
+
+							r, c := t.view.GetSelection()
+							key, actions, handler, currentStatus, refreshFunc := t.moveFunc(r, c)()
+
+							currentStatusIdx := func() int {
+								for i, btn := range actions {
+									if btn == currentStatus {
+										return i
+									}
+								}
+								return 0
+							}
+
+							t.action.ClearButtons().AddButtons(actions).SetFocus(currentStatusIdx())
+							t.action.SetText(
+								fmt.Sprintf("Select desired state to transition %s to:", key),
+							)
+
+							t.action.SetDoneFunc(func(btnIndex int, btnLabel string) {
+								t.action.GetFooter().SetText("Processing. Please wait...").SetTextColor(tcell.ColorGray)
+								t.screen.ForceDraw()
+
+								err := handler(btnLabel)
+								if err != nil {
+									t.action.GetFooter().SetText(
+										fmt.Sprintf("Error: %s", err.Error()),
+									).SetTextColor(tcell.ColorRed)
+									return
+								}
+								t.painter.HidePage("action")
+								refreshContextInFooter()
+
+								if refreshFunc != nil {
+									refreshFunc(r, c, btnLabel)
+									_ = t.Paint(t.data)
+								}
+							})
+						}()
+
 						// Refresh the screen.
 						t.screen.Draw()
 					}()
